@@ -8,8 +8,8 @@ OC.L10N.register(
     "Cheers!" : "¡Saludos!",
     "Calendar" : "Calendario",
     "Confirm" : "Confirmar",
+    "Description:" : "Descripción:",
     "Where:" : "Dónde:",
-    "New event" : "Nuevo evento",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
@@ -25,16 +25,20 @@ OC.L10N.register(
     "Deleted" : "Borrado",
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
+    "Deck" : "Deck",
+    "Hidden" : "Oculto",
     "Share link" : "Compartir liga",
     "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
+    "Save" : "Guardar",
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
-    "or" : "o",
     "List view" : "Vista de lista",
     "Actions" : "Acciones",
+    "or" : "o",
     "Show week numbers" : "Mostrar número de semana",
+    "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
     "to" : "para",
@@ -46,36 +50,33 @@ OC.L10N.register(
     "Friday" : "Viernes",
     "Saturday" : "Sábado",
     "Sunday" : "Domingo",
-    "Save" : "Guardar",
-    "Update" : "Actualizar",
     "Your email address" : "Tu dirección de correo electrónico",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
-    "Delete file" : "Borrar archivo",
+    "days" : "días",
+    "weeks" : "semanas",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
+    "Delete file" : "Borrar archivo",
     "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
-    "Send email" : "Enviar correo electrónico",
+    "Attendees" : "Asistentes",
     "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
     "available" : "disponible",
-    "More" : "Más",
     "Global" : "Global",
+    "Subscribe" : "Suscribir",
     "Personal" : "Personal",
     "Details" : "Detalles",
-    "Attendees" : "Asistentes",
     "Resources" : "Recursos",
     "Close" : "Cerrar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
-    "Prev" : "Prev",
-    "Next" : "Siguiente",
     "Other" : "Otro",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
@@ -83,9 +84,6 @@ OC.L10N.register(
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
-    "Talk" : "Hablar",
-    "Mail" : "Correo",
-    "Birthday" : "Fecha de nacimiento",
     "User not found" : "No se encontró el usuario"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
