@@ -1,7 +1,9 @@
 OC.L10N.register(
     "calendar",
     {
-    "%s has published the calendar »%s«" : "%s avaldas kalendri »%s«",
+    "Provided email-address is too long" : "Sisestatud e-postiaadress on liiga pikk",
+    "Provided email-address is not valid" : "Sisestatud e-postiaadress pole korrektne",
+    "%s has published the calendar »%s«" : "%s avaldas kalendri „%s“",
     "Hello," : "Tere,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Tahtsime Sind informeerida, et %s on avaldanud kalendri»%s«.",
     "Open »%s«" : "Ava »%s«",
@@ -16,6 +18,7 @@ OC.L10N.register(
     "Date:" : "Kuupäev:",
     "Where:" : "Kus:",
     "Comment:" : "Kommentaar:",
+    "A Calendar app for Nextcloud" : "Nextcloudi kalendrirakendus",
     "Previous day" : "Eelmine päev",
     "Previous week" : "Eelmine nädal",
     "Previous year" : "Eelmine aasta",
@@ -37,10 +40,14 @@ OC.L10N.register(
     "Edit" : "Redigeeri",
     "Delete" : "Kustuta",
     "Untitled calendar" : "Nimetu kalender",
+    "Shared with you by" : "Seda jagas sinuga",
+    "Edit and share calendar" : "Muuda ja jaga kalendrit",
     "Edit calendar" : "Muuda kalendrit",
     "Calendars" : "Kalendrid",
     "Add new" : "Lisa uus",
     "New calendar" : "Uus kalender",
+    "Name for new calendar" : "Uue kalendri nimi",
+    "Calendar link copied to clipboard." : "Kalendri link kopeeriti lõikelauale.",
     "Export" : "Ekspordi",
     "Empty trash bin" : "Tühjenda prügikast",
     "Trash bin" : "Prügikast",
@@ -48,23 +55,38 @@ OC.L10N.register(
     "Deleted" : "Kustutatud",
     "Restore" : "Taasta",
     "Delete permanently" : "Kustuta jäädavalt",
+    "Shared calendars" : "Jagatud kalendrid",
     "Deck" : "Deck",
     "Hidden" : "Peidetud",
     "Internal link" : "Sisemine link",
     "Copy internal link" : "Kopeeri sisemine link",
-    "Share link" : "Jaga link",
+    "Share link" : "Jaga linki",
     "Copy public link" : "Kopeeri avalik link",
+    "Send link to calendar via email" : "Saada link kalendrisse e-posti teel",
+    "Enter one address" : "Sisesta üks aadress",
     "Delete share link" : "Kustuta jagamise link",
     "can edit" : "saab muuta",
     "Unshare with {displayName}" : "Lõpeta jagamine kasutajaga: {displayName}",
     "Share with users or groups" : "Jaga kasutajate või gruppidega",
     "No users or groups" : "Ei ole kasutajaid või gruppe",
+    "Failed to save calendar name and color" : "Kalendri värvi ja nime salvestamine ei õnnestunud",
+    "Calendar name …" : "Kalendri nimi…",
+    "Never show me as busy (set this calendar to transparent)" : "Ära iialgi näita, et ma olen hõivatud (muuda see kalender läbipaistvaks)",
+    "Share calendar" : "Jaga kalendrit",
+    "Unshare from me" : "Eemalda minult see jagamine",
     "Save" : "Salvesta",
     "Import calendars" : "Impordi kalendrid",
-    "Filename" : "Faili nimi",
+    "Please select a calendar to import into …" : "Palun vali kalender, kuhu soovid importida…",
+    "Filename" : "Failinimi",
     "Cancel" : "Loobu",
+    "_Import calendar_::_Import calendars_" : ["Impordi kalender","Impordi kalendrid"],
+    "Select the default location for attachments" : "Vali manustele vaikimisi asukoht",
+    "Pick" : "Vali",
     "Invalid location selected" : "Vigane asukoht valitud",
+    "Attachments folder successfully saved." : "Manuste kausta salvestamine õnnestus.",
+    "Error on saving attachments folder." : "Viga manuste kausta salvestamisel.",
     "Automatic" : "Automaatne",
+    "Navigation" : "Liikumine",
     "Previous period" : "Eelmine periood",
     "Next period" : "Järgmine periood",
     "Views" : "Vaated",
@@ -99,9 +121,16 @@ OC.L10N.register(
     "Saturday" : "Laupäev",
     "Sunday" : "Pühapäev",
     "Your email address" : "Sinu e-posti aadress",
+    "Back" : "Tagasi",
+    "Create a new conversation" : "Loo uus vestlus",
     "Notification" : "Teavitus",
     "Email" : "E-post",
+    "Audio notification" : "Heliteavitus",
+    "Other notification" : "Muu teavitus",
     "On date" : "Kuupäeval",
+    "Edit time" : "Muuda aega",
+    "Remove reminder" : "Eemalda meeldetuletus",
+    "Add reminder" : "Lisa meeldetuletus",
     "seconds" : "sekundit",
     "minutes" : "minutit",
     "hours" : "tundi",
@@ -114,6 +143,7 @@ OC.L10N.register(
     "Upload from device" : "Laadi üles seadmest",
     "Delete file" : "Kustuta fail",
     "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
+    "Not available" : "Pole saadaval",
     "Out of office" : "Kontorist väljas",
     "Unknown" : "Teadmata",
     "Done" : "Valmis",
@@ -134,6 +164,7 @@ OC.L10N.register(
     "Does not repeat" : "Ei kordu",
     "Global" : "Üldine",
     "Subscribe" : "Telli",
+    "Select a date" : "Vali kuupäev",
     "Personal" : "Isiklik",
     "Details" : "Üksikasjad",
     "Invite" : "Kutse",
@@ -148,13 +179,19 @@ OC.L10N.register(
     "Monthly" : "Igakuine",
     "Yearly" : "Igaastane",
     "second" : "teine",
+    "Untitled task" : "Ilma nimeta pealkiri",
     "Other" : "Muu",
     "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
     "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
     "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
     "Status" : "Staatus",
     "Confirmed" : "Kinnitatud",
+    "Canceled" : "Tühistatud",
     "Categories" : "Kategooriad",
-    "User not found" : "Kasutajat ei leitud"
+    "Error while sharing file" : "Viga faili jagamisel",
+    "User not found" : "Kasutajat ei leitud",
+    "[Today]" : "[Täna]",
+    "[Tomorrow]" : "[Homme]",
+    "[Yesterday]" : "[Eile]"
 },
 "nplurals=2; plural=(n != 1);");
